openai

package
v0.1.13 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 15, 2026 License: AGPL-3.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func HandleSpeech

func HandleSpeech(c echo.Context, options mo.Option[types.SpeechRequestOptions]) mo.Result[any]

func ListVoices added in v0.1.12

func ListVoices(_ context.Context) ([]types.Voice, error)

ListVoices returns the static list of OpenAI TTS voices. OpenAI's TTS voice catalog is not fetched from an API — it's documented static data, so this function is credential-free and always succeeds.

Types

This section is empty.

Jump to